==> ark-23.08.4.tar.xz: ark-23.08.4/plugins/cliarjplugin/kerfuffle_cliarj.json.cmake <==
{
    "KPlugin": {
        "Description": "Full support for the ARJ archive formats",
        "Description[ar]": "دعم كامل لتنسيقات الأرشيف ARJ",
        "Description[ast]": "Compatibilidá completa col formatu d'archivu ARj",
        "Description[az]": "ARJ formatlı arxivlərin tam dəstəklənməsi",
        "Description[be]": "Поўная падтрымка фармату ARJ",
        "Description[bg]": "Пълна поддръжка на архивен формат ARJ",
        "Description[ca@valencia]": "Implementació completa del format d'arxiu ARJ",
        "Description[ca]": "Implementació completa del format d'arxiu ARJ",
        "Description[cs]": "Plná podpora archivačních formátů ARJ",
        "Description[de]": "Vollständige Unterstützung für das ARJ-Archivformat",
        "Description[el]": "Πλήρης υποστήριξη για τον τύπο αρχειοθήκης ARJ",
        "Description[en_GB]": "Full support for the ARJ archive formats",
        "Description[eo]": "Plena subteno por la ARJ-arkivoformato",
        "Description[es]": "Uso total de los formatos de archivo comprimido ARJ",
        "Description[eu]": "ARJ artxibo formatuaren euskarri osoa",
        "Description[fi]": "Täysi ARJ-tiedostomuodon tuki",
        "Description[fr]": "Prise en charge complète des formats d'archive « ARJ »",
        "Description[gl]": "Compatibilidade total cos formatos de arquivo ARJ.",
        "Description[ia]": "Supporto complete per le formato de archivo ARJ",
        "Description[ie]": "Complet supporte por archives del formate ARJ",
        "Description[it]": "Supporto completo per il formato di archivi ARJ",
        "Description[ka]": "ARJ არქვივების სრული მხარდაჭერა",
        "Description[ko]": "ARK 압축 형식 전체 지원",
        "Description[nl]": "Volledige ondersteuning voor de ARJ-archiefformaten",
        "Description[nn]": "Full støtte for arkivformatet ARJ",
        "Description[pl]": "Pełna obsługa dla archiwów ARJ",
        "Description[pt]": "Suporte total para o formato de pacotes ARJ",
        "Description[pt_BR]": "Suporte total para o formato de arquivos ARJ",
        "Description[ru]": "Полная поддержка архивов ARJ",
        "Description[sl]": "Polna podpora za arhive vrste ARJ",
        "Description[sv]": "Fullt stöd för ARJ arkivformat",
        "Description[tr]": "ARJ arşiv biçimi için tam destek",
        "Description[uk]": "Повноцінна підтримка архівів у форматі ARJ",
        "Description[x-test]": "xxFull support for the ARJ archive formatsxx",
        "Description[zh_CN]": "完整支持 ARJ 压缩文件格式",
        "Description[zh_TW]": "對 ARJ 壓縮檔格式的完整支援",
        "Id": "kerfuffle_cliarj",
        "MimeTypes": [
            "application/x-arj",
            "application/arj"
        ],
        "Name": "ARJ plugin",
        "Name[ar]": "ملحق ARJ",
        "Name[ast]": "Plugin d'ARJ",
        "Name[az]": "ARJ qoşması",
        "Name[be]": "Убудова ARJ",
        "Name[bg]": "Приставка ARJ",
        "Name[ca@valencia]": "Connector d'ARJ",
        "Name[ca]": "Connector de l'ARJ",
        "Name[cs]": "Modul pro ARJ",
        "Name[de]": "ARJ-Modul",
        "Name[el]": "Πρόσθετο ARJ",
        "Name[en_GB]": "ARJ plugin",
        "Name[eo]": "ARJ-kromaĵo",
        "Name[es]": "Complemento ARJ",
        "Name[eu]": "ARJ plugina",
        "Name[fi]": "ARJ-liitännäinen",
        "Name[fr]": "Module externe « ARJ »",
        "Name[gl]": "Complemento de ARJ",
        "Name[ia]": "Plug-in ARJ",
        "Name[ie]": "Plugin ARJ",
        "Name[it]": "Estensione ARJ",
        "Name[ka]": "ARJ -ის მხარდაჭერა",
        "Name[ko]": "ARJ 플러그인",
        "Name[nl]": "ARJ-plug-in",
        "Name[nn]": "ARJ-tillegg",
        "Name[pl]": "Wtyczka ARJ",
        "Name[pt]": "'Plugin' do ARJ",
        "Name[pt_BR]": "Plugin ARJ",
        "Name[ru]": "Модуль ARJ",
        "Name[sl]": "Vstavek ARJ",
        "Name[sv]": "ARJ-insticksprogram",
        "Name[ta]": "ARJ செருகுநிரல்",
        "Name[tr]": "ARJ eklentisi",
        "Name[uk]": "Додаток ARJ",
        "Name[x-test]": "xxARJ pluginxx",
        "Name[zh_CN]": "ARJ 插件",
        "Name[zh_TW]": "ARJ 外掛程式",
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadOnlyExecutables": [
        "arj"
    ],
    "X-KDE-Kerfuffle-ReadWrite": true,
    "X-KDE-Kerfuffle-ReadWriteExecutables": [
        "arj"
    ],
    "X-KDE-Priority": 100,
    "application/arj": {
        "CompressionMethodDefault": "Good (default)",
        "CompressionMethods": {
            "FAST! less comp.": "3",
            "FASTEST! least comp.": "4",
            "Good (default)": "1",
            "Less mem. and comp.": "2",
            "Store (no compression)": "0"
        },
        "Encryption": true,
        "EncryptionMethodDefault": "Standard",
        "EncryptionMethods": [
            "Standard",
            "arjcrypt.so",
            "GOST 40-bit"
        ],
        "SupportsMultiVolume": true,
        "SupportsTesting": true,
        "SupportsWriteComment": true
    },
    "application/x-arj": {
        "CompressionMethodDefault": "Good (default)",
        "CompressionMethods": {
            "FAST! less comp.": "3",
            "FASTEST! least comp.": "4",
            "Good (default)": "1",
            "Less mem. and comp.": "2",
            "Store (no compression)": "0"
        },
        "Encryption": true,
        "EncryptionMethodDefault": "Standard",
        "EncryptionMethods": [
            "Standard",
            "arjcrypt.so",
            "GOST 40-bit"
        ],
        "SupportsMultiVolume": true,
        "SupportsTesting": true,
        "SupportsWriteComment": true
    }
}

==> ark_23.08.5.orig.tar.xz: ark-23.08.5/plugins/cliarjplugin/kerfuffle_cliarj.json.cmake <==
{
    "KPlugin": {
        "Description": "Full support for the ARJ archive formats",
        "Description[ar]": "دعم كامل لتنسيقات الأرشيف ARJ",
        "Description[ast]": "Compatibilidá completa col formatu d'archivu ARj",
        "Description[az]": "ARJ formatlı arxivlərin tam dəstəklənməsi",
        "Description[be]": "Поўная падтрымка фармату ARJ",
        "Description[bg]": "Пълна поддръжка на архивен формат ARJ",
        "Description[ca@valencia]": "Implementació completa del format d'arxiu ARJ",
        "Description[ca]": "Implementació completa del format d'arxiu ARJ",
        "Description[cs]": "Plná podpora archivačních formátů ARJ",
        "Description[de]": "Vollständige Unterstützung für das ARJ-Archivformat",
        "Description[el]": "Πλήρης υποστήριξη για τον τύπο αρχειοθήκης ARJ",
        "Description[en_GB]": "Full support for the ARJ archive formats",
        "Description[eo]": "Plena subteno por la ARJ-arkivoformato",
        "Description[es]": "Uso total de los formatos de archivo comprimido ARJ",
        "Description[eu]": "ARJ artxibo formatuaren euskarri osoa",
        "Description[fi]": "Täysi ARJ-tiedostomuodon tuki",
        "Description[fr]": "Prise en charge complète des formats d'archive « ARJ »",
        "Description[gl]": "Compatibilidade total cos formatos de arquivo ARJ.",
        "Description[ia]": "Supporto complete per le formato de archivo ARJ",
        "Description[ie]": "Complet supporte por archives del formate ARJ",
        "Description[it]": "Supporto completo per il formato di archivi ARJ",
        "Description[ja]": "ARJ アーカイブ形式のフルサポート",
        "Description[ka]": "ARJ არქვივების სრული მხარდაჭერა",
        "Description[ko]": "ARK 압축 형식 전체 지원",
        "Description[nl]": "Volledige ondersteuning voor de ARJ-archiefformaten",
        "Description[nn]": "Full støtte for arkivformatet ARJ",
        "Description[pl]": "Pełna obsługa dla archiwów ARJ",
        "Description[pt]": "Suporte total para o formato de pacotes ARJ",
        "Description[pt_BR]": "Suporte total para o formato de arquivos ARJ",
        "Description[ro]": "Suport deplin pentru formatul de arhivă ARJ",
        "Description[ru]": "Полная поддержка архивов ARJ",
        "Description[sl]": "Polna podpora za arhive vrste ARJ",
        "Description[sv]": "Fullt stöd för ARJ arkivformat",
        "Description[tr]": "ARJ arşiv biçimi için tam destek",
        "Description[uk]": "Повноцінна підтримка архівів у форматі ARJ",
        "Description[x-test]": "xxFull support for the ARJ archive formatsxx",
        "Description[zh_CN]": "完整支持 ARJ 压缩文件格式",
        "Description[zh_TW]": "對 ARJ 壓縮檔格式的完整支援",
        "Id": "kerfuffle_cliarj",
        "MimeTypes": [
            "application/x-arj",
            "application/arj"
        ],
        "Name": "ARJ plugin",
        "Name[ar]": "ملحق ARJ",
        "Name[ast]": "Plugin d'ARJ",
        "Name[az]": "ARJ qoşması",
        "Name[be]": "Убудова ARJ",
        "Name[bg]": "Приставка ARJ",
        "Name[ca@valencia]": "Connector d'ARJ",
        "Name[ca]": "Connector de l'ARJ",
        "Name[cs]": "Modul pro ARJ",
        "Name[de]": "ARJ-Modul",
        "Name[el]": "Πρόσθετο ARJ",
        "Name[en_GB]": "ARJ plugin",
        "Name[eo]": "ARJ-kromaĵo",
        "Name[es]": "Complemento ARJ",
        "Name[eu]": "ARJ plugina",
        "Name[fi]": "ARJ-liitännäinen",
        "Name[fr]": "Module externe « ARJ »",
        "Name[gl]": "Complemento de ARJ",
        "Name[ia]": "Plug-in ARJ",
        "Name[ie]": "Plugin ARJ",
        "Name[it]": "Estensione ARJ",
        "Name[ja]": "ARJ プラグイン",
        "Name[ka]": "ARJ -ის მხარდაჭერა",
        "Name[ko]": "ARJ 플러그인",
        "Name[nl]": "ARJ-plug-in",
        "Name[nn]": "ARJ-tillegg",
        "Name[pl]": "Wtyczka ARJ",
        "Name[pt]": "'Plugin' do ARJ",
        "Name[pt_BR]": "Plugin ARJ",
        "Name[ro]": "Extensie ARJ",
        "Name[ru]": "Модуль ARJ",
        "Name[sk]": "Plugin ARJ",
        "Name[sl]": "Vstavek ARJ",
        "Name[sv]": "ARJ-insticksprogram",
        "Name[ta]": "ARJ செருகுநிரல்",
        "Name[tr]": "ARJ eklentisi",
        "Name[uk]": "Додаток ARJ",
        "Name[x-test]": "xxARJ pluginxx",
        "Name[zh_CN]": "ARJ 插件",
        "Name[zh_TW]": "ARJ 外掛程式",
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadOnlyExecutables": [
        "arj"
    ],
    "X-KDE-Kerfuffle-ReadWrite": true,
    "X-KDE-Kerfuffle-ReadWriteExecutables": [
        "arj"
    ],
    "X-KDE-Priority": 100,
    "application/arj": {
        "CompressionMethodDefault": "Good (default)",
        "CompressionMethods": {
            "FAST! less comp.": "3",
            "FASTEST! least comp.": "4",
            "Good (default)": "1",
            "Less mem. and comp.": "2",
            "Store (no compression)": "0"
        },
        "Encryption": true,
        "EncryptionMethodDefault": "Standard",
        "EncryptionMethods": [
            "Standard",
            "arjcrypt.so",
            "GOST 40-bit"
        ],
        "SupportsMultiVolume": true,
        "SupportsTesting": true,
        "SupportsWriteComment": true
    },
    "application/x-arj": {
        "CompressionMethodDefault": "Good (default)",
        "CompressionMethods": {
            "FAST! less comp.": "3",
            "FASTEST! least comp.": "4",
            "Good (default)": "1",
            "Less mem. and comp.": "2",
            "Store (no compression)": "0"
        },
        "Encryption": true,
        "EncryptionMethodDefault": "Standard",
        "EncryptionMethods": [
            "Standard",
            "arjcrypt.so",
            "GOST 40-bit"
        ],
        "SupportsMultiVolume": true,
        "SupportsTesting": true,
        "SupportsWriteComment": true
    }
}
